@@ -4,7 +4,9 @@ import tempfile
 from typing import List, Optional
 
 import click
-from models import (
+
+from ubuntu_cloud_image_changelog import launchpadagent, lib
+from ubuntu_cloud_image_changelog.models import (
     Added,
     ChangelogModel,
     DebPackage,
@@ -18,8 +20,6 @@ from models import (
     ToVersion,
 )
 
-from ubuntu_cloud_image_changelog import launchpadagent, lib
-
 
 @click.group()
 @click.pass_context
